@@ -23,36 +23,37 @@ else:
 
 __all__ = (
     "ClaimDevicesByClaimCodeRequestRequestTypeDef",
-    "ClaimDevicesByClaimCodeResponseTypeDef",
-    "DescribeDeviceRequestRequestTypeDef",
-    "DescribeDeviceResponseTypeDef",
-    "DeviceDescriptionTypeDef",
-    "DeviceEventTypeDef",
-    "DeviceMethodTypeDef",
-    "DeviceTypeDef",
-    "FinalizeDeviceClaimRequestRequestTypeDef",
-    "FinalizeDeviceClaimResponseTypeDef",
-    "GetDeviceMethodsRequestRequestTypeDef",
-    "GetDeviceMethodsResponseTypeDef",
-    "InitiateDeviceClaimRequestRequestTypeDef",
-    "InitiateDeviceClaimResponseTypeDef",
-    "InvokeDeviceMethodRequestRequestTypeDef",
-    "InvokeDeviceMethodResponseTypeDef",
-    "ListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
-    "ListDeviceEventsRequestRequestTypeDef",
-    "ListDeviceEventsResponseTypeDef",
-    "ListDevicesRequestListDevicesPaginateTypeDef",
-    "ListDevicesRequestRequestTypeDef",
-    "ListDevicesResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
+    "DescribeDeviceRequestRequestTypeDef",
+    "DeviceDescriptionTypeDef",
+    "DeviceTypeDef",
+    "DeviceMethodTypeDef",
+    "FinalizeDeviceClaimRequestRequestTypeDef",
+    "GetDeviceMethodsRequestRequestTypeDef",
+    "InitiateDeviceClaimRequestRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "ListDeviceEventsRequestRequestTypeDef",
+    "ListDevicesRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UnclaimDeviceRequestRequestTypeDef",
-    "UnclaimDeviceResponseTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateDeviceStateRequestRequestTypeDef",
+    "ClaimDevicesByClaimCodeResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "FinalizeDeviceClaimResponseTypeDef",
+    "InitiateDeviceClaimResponseTypeDef",
+    "InvokeDeviceMethodResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "UnclaimDeviceResponseTypeDef",
+    "DescribeDeviceResponseTypeDef",
+    "ListDevicesResponseTypeDef",
+    "DeviceEventTypeDef",
+    "GetDeviceMethodsResponseTypeDef",
+    "InvokeDeviceMethodRequestRequestTypeDef",
+    "ListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
+    "ListDevicesRequestListDevicesPaginateTypeDef",
+    "ListDeviceEventsResponseTypeDef",
 )
 
 ClaimDevicesByClaimCodeRequestRequestTypeDef = TypedDict(
@@ -62,12 +63,14 @@ ClaimDevicesByClaimCodeRequestRequestTypeDef = TypedDict(
     },
 )
 
-ClaimDevicesByClaimCodeResponseTypeDef = TypedDict(
-    "ClaimDevicesByClaimCodeResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ClaimCode": str,
-        "Total": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -78,14 +81,6 @@ DescribeDeviceRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeDeviceResponseTypeDef = TypedDict(
-    "DescribeDeviceResponseTypeDef",
-    {
-        "DeviceDescription": "DeviceDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DeviceDescriptionTypeDef = TypedDict(
     "DeviceDescriptionTypeDef",
     {
@@ -100,11 +95,12 @@ DeviceDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-DeviceEventTypeDef = TypedDict(
-    "DeviceEventTypeDef",
+DeviceTypeDef = TypedDict(
+    "DeviceTypeDef",
     {
-        "Device": "DeviceTypeDef",
-        "StdEvent": str,
+        "Attributes": Dict[str, Any],
+        "DeviceId": str,
+        "Type": str,
     },
     total=False,
 )
@@ -118,16 +114,6 @@ DeviceMethodTypeDef = TypedDict(
     total=False,
 )
 
-DeviceTypeDef = TypedDict(
-    "DeviceTypeDef",
-    {
-        "Attributes": Dict[str, Any],
-        "DeviceId": str,
-        "Type": str,
-    },
-    total=False,
-)
-
 _RequiredFinalizeDeviceClaimRequestRequestTypeDef = TypedDict(
     "_RequiredFinalizeDeviceClaimRequestRequestTypeDef",
     {
@@ -150,14 +136,6 @@ class FinalizeDeviceClaimRequestRequestTypeDef(
     pass
 
 
-FinalizeDeviceClaimResponseTypeDef = TypedDict(
-    "FinalizeDeviceClaimResponseTypeDef",
-    {
-        "State": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetDeviceMethodsRequestRequestTypeDef = TypedDict(
     "GetDeviceMethodsRequestRequestTypeDef",
     {
@@ -165,14 +143,6 @@ GetDeviceMethodsRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetDeviceMethodsResponseTypeDef = TypedDict(
-    "GetDeviceMethodsResponseTypeDef",
-    {
-        "DeviceMethods": List["DeviceMethodTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 InitiateDeviceClaimRequestRequestTypeDef = TypedDict(
     "InitiateDeviceClaimRequestRequestTypeDef",
     {
@@ -180,69 +150,16 @@ InitiateDeviceClaimRequestRequestTypeDef = TypedDict(
     },
 )
 
-InitiateDeviceClaimResponseTypeDef = TypedDict(
-    "InitiateDeviceClaimResponseTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "State": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredInvokeDeviceMethodRequestRequestTypeDef = TypedDict(
-    "_RequiredInvokeDeviceMethodRequestRequestTypeDef",
-    {
-        "DeviceId": str,
-    },
-)
-_OptionalInvokeDeviceMethodRequestRequestTypeDef = TypedDict(
-    "_OptionalInvokeDeviceMethodRequestRequestTypeDef",
-    {
-        "DeviceMethod": "DeviceMethodTypeDef",
-        "DeviceMethodParameters": str,
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class InvokeDeviceMethodRequestRequestTypeDef(
-    _RequiredInvokeDeviceMethodRequestRequestTypeDef,
-    _OptionalInvokeDeviceMethodRequestRequestTypeDef,
-):
-    pass
-
-
-InvokeDeviceMethodResponseTypeDef = TypedDict(
-    "InvokeDeviceMethodResponseTypeDef",
-    {
-        "DeviceMethodResponse": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef = TypedDict(
-    "_RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
-    {
-        "DeviceId": str,
-        "FromTimeStamp": Union[datetime, str],
-        "ToTimeStamp": Union[datetime, str],
-    },
-)
-_OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef = TypedDict(
-    "_OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListDeviceEventsRequestListDeviceEventsPaginateTypeDef(
-    _RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef,
-    _OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListDeviceEventsRequestRequestTypeDef = TypedDict(
     "_RequiredListDeviceEventsRequestRequestTypeDef",
     {
@@ -267,24 +184,6 @@ class ListDeviceEventsRequestRequestTypeDef(
     pass
 
 
-ListDeviceEventsResponseTypeDef = TypedDict(
-    "ListDeviceEventsResponseTypeDef",
-    {
-        "Events": List["DeviceEventTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListDevicesRequestListDevicesPaginateTypeDef = TypedDict(
-    "ListDevicesRequestListDevicesPaginateTypeDef",
-    {
-        "DeviceType": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListDevicesRequestRequestTypeDef = TypedDict(
     "ListDevicesRequestRequestTypeDef",
     {
@@ -295,15 +194,6 @@ ListDevicesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListDevicesResponseTypeDef = TypedDict(
-    "ListDevicesResponseTypeDef",
-    {
-        "Devices": List["DeviceDescriptionTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -311,35 +201,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -355,14 +216,6 @@ UnclaimDeviceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UnclaimDeviceResponseTypeDef = TypedDict(
-    "UnclaimDeviceResponseTypeDef",
-    {
-        "State": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -390,3 +243,159 @@ class UpdateDeviceStateRequestRequestTypeDef(
     _RequiredUpdateDeviceStateRequestRequestTypeDef, _OptionalUpdateDeviceStateRequestRequestTypeDef
 ):
     pass
+
+
+ClaimDevicesByClaimCodeResponseTypeDef = TypedDict(
+    "ClaimDevicesByClaimCodeResponseTypeDef",
+    {
+        "ClaimCode": str,
+        "Total": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+FinalizeDeviceClaimResponseTypeDef = TypedDict(
+    "FinalizeDeviceClaimResponseTypeDef",
+    {
+        "State": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+InitiateDeviceClaimResponseTypeDef = TypedDict(
+    "InitiateDeviceClaimResponseTypeDef",
+    {
+        "State": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+InvokeDeviceMethodResponseTypeDef = TypedDict(
+    "InvokeDeviceMethodResponseTypeDef",
+    {
+        "DeviceMethodResponse": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UnclaimDeviceResponseTypeDef = TypedDict(
+    "UnclaimDeviceResponseTypeDef",
+    {
+        "State": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeDeviceResponseTypeDef = TypedDict(
+    "DescribeDeviceResponseTypeDef",
+    {
+        "DeviceDescription": DeviceDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListDevicesResponseTypeDef = TypedDict(
+    "ListDevicesResponseTypeDef",
+    {
+        "Devices": List[DeviceDescriptionTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeviceEventTypeDef = TypedDict(
+    "DeviceEventTypeDef",
+    {
+        "Device": DeviceTypeDef,
+        "StdEvent": str,
+    },
+    total=False,
+)
+
+GetDeviceMethodsResponseTypeDef = TypedDict(
+    "GetDeviceMethodsResponseTypeDef",
+    {
+        "DeviceMethods": List[DeviceMethodTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredInvokeDeviceMethodRequestRequestTypeDef = TypedDict(
+    "_RequiredInvokeDeviceMethodRequestRequestTypeDef",
+    {
+        "DeviceId": str,
+    },
+)
+_OptionalInvokeDeviceMethodRequestRequestTypeDef = TypedDict(
+    "_OptionalInvokeDeviceMethodRequestRequestTypeDef",
+    {
+        "DeviceMethod": DeviceMethodTypeDef,
+        "DeviceMethodParameters": str,
+    },
+    total=False,
+)
+
+
+class InvokeDeviceMethodRequestRequestTypeDef(
+    _RequiredInvokeDeviceMethodRequestRequestTypeDef,
+    _OptionalInvokeDeviceMethodRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef = TypedDict(
+    "_RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
+    {
+        "DeviceId": str,
+        "FromTimeStamp": Union[datetime, str],
+        "ToTimeStamp": Union[datetime, str],
+    },
+)
+_OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef = TypedDict(
+    "_OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListDeviceEventsRequestListDeviceEventsPaginateTypeDef(
+    _RequiredListDeviceEventsRequestListDeviceEventsPaginateTypeDef,
+    _OptionalListDeviceEventsRequestListDeviceEventsPaginateTypeDef,
+):
+    pass
+
+
+ListDevicesRequestListDevicesPaginateTypeDef = TypedDict(
+    "ListDevicesRequestListDevicesPaginateTypeDef",
+    {
+        "DeviceType": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListDeviceEventsResponseTypeDef = TypedDict(
+    "ListDeviceEventsResponseTypeDef",
+    {
+        "Events": List[DeviceEventTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
